@@ -14,11 +14,17 @@
 
 #include "gulp.h"
 
+#ifndef GNOMELOCALEDIR
+#define GNOMELOCALEDIR "/usr/share/locale"
+#endif
+
+#include <libgnome/gnome-i18n.h>
+
 void
 do_message(char *msg)
 {
 	GtkWidget *msgbox = gnome_message_box_new(msg,
-				GNOME_MESSAGE_BOX_WARNING, "Close", NULL);
+				GNOME_MESSAGE_BOX_WARNING, _("Close"), NULL);
 	gnome_dialog_run(GNOME_DIALOG(msgbox));
 }
 
@@ -27,14 +33,14 @@ do_message(char *msg)
 {
 	GtkWidget *about;
 	static const char *authors[] = {
-		"Elliot Lee (sopwith@cuc.edu)",
-		"Federico Mena (quartic@gimp.org)",
+		N_("Elliot Lee (sopwith@cuc.edu)"),
+		N_("Federico Mena (quartic@gimp.org)"),
 		NULL
 	};
 	
 	about = gnome_about_new ( _("GULP"), VERSION,
 				  /* copyright notice */
-				  "(C) 1998 the Free Software Foundation",
+				  _("(C) 1998 the Free Software Foundation"),
 				  authors,
 			 /* another comments */
 				  _("GNOME Unified Link to Printers program."),
@@ -165,7 +171,7 @@ do_message(char *msg)
       [self set_wait_cursor:FALSE];
     }
   else
-    printf("Click on unknown widget\n");
+    printf(_("Click on unknown widget\n"));
 	
   if (opstatus)
 	do_message(_("Operation failed"));
@@ -198,10 +204,10 @@ do_message(char *msg)
   char idbuf[30], sizebuf[10];
   gchar *vals[4];
   static const char *collist[] = {
-    "Job ID",
-    "Filenames",
-    "Size",
-    "Owner"
+    N_("Job ID"),
+    N_("Filenames"),
+    N_("Size"),
+    N_("Owner")
   };
   int oldoffset = -1;
   GList *anitem;
@@ -276,10 +282,10 @@ do_message(char *msg)
 - do_printer_list
 {
   gchar *columns[] = {
-    "Printer",
-    "Jobs",
-    "Queueing",
-    "Printing"
+    N_("Printer"),
+    N_("Jobs"),
+    N_("Queueing"),
+    N_("Printing")
   };
   gchar *tmp;
   Printer *cp;
@@ -299,7 +305,7 @@ do_message(char *msg)
 	    if (anitem->data == [printer_list get_row_data:GPOINTER_TO_INT(printer_list->gtkclist->selection->data)])
 	      {
 		oldoffset = i;
-		g_print("oldoffset for printer_list is %d\n",
+		g_print(_("oldoffset for printer_list is %d\n"),
 			oldoffset);
 		break;
 	      }
@@ -322,7 +328,7 @@ do_message(char *msg)
   for (cnt = 0; cnt < printsys->numprinters; cnt++)
     {
       i = [printer_list appendCListRow:(const char **)columns];
-      g_print("Doing row %d\n", i);
+      g_print(_("Doing row %d\n"), i);
       cp = printsys->printers[cnt];
 
       [printer_list set_text:i :0 :(char *) [[cp getJobs] getQueueName]];
@@ -338,7 +344,7 @@ do_message(char *msg)
 	[printer_list set_pixmap:i :3 :yes_pixmap :yes_mask];
       else
 	[printer_list set_pixmap:i :3 :no_pixmap :no_mask];
-      g_print("Setting row data %d to %#lx\n", i, (long) cp);
+      g_print(_("Setting row data %d to %#lx\n"), i, (long) cp);
       [printer_list set_row_data:i rowData:cp];
     }
   g_free(tmp);
@@ -374,7 +380,7 @@ do_message(char *msg)
   id  vbox;
 
   GnomeUIInfo filemenu[] = {
-    { GNOME_APP_UI_ITEM, "E_xit", NULL, "menu_file_exit", NULL, NULL, 
+    { GNOME_APP_UI_ITEM, N_("E_xit"), NULL, "menu_file_exit", NULL, NULL, 
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', GDK_CONTROL_MASK, NULL},
     { GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
@@ -382,15 +388,15 @@ do_message(char *msg)
   GnomeUIInfo helpmenu[] = {
     { GNOME_APP_UI_HELP, NULL, NULL, "gulp", NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-    { GNOME_APP_UI_ITEM, "_About...", NULL, "menu_help_about", NULL, NULL,
+    { GNOME_APP_UI_ITEM, N_("_About..."), NULL, "menu_help_about", NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
     { GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
   };
   GnomeUIInfo mainmenu[] = {
-    { GNOME_APP_UI_SUBTREE, "_Program", NULL, &filemenu, NULL, NULL,
+    { GNOME_APP_UI_SUBTREE, N_("_Program"), NULL, &filemenu, NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-    { GNOME_APP_UI_SUBTREE, "_Help", NULL, &helpmenu, NULL, NULL,
+    { GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, &helpmenu, NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
     { GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
@@ -538,6 +544,10 @@ do_message(char *msg)
 int main(int argc, char *argv[])
 {
   id myapp = [GULPApp alloc];
+
+  bindtextdomain(PACKAGE, GNOMELOCALEDIR);
+  textdomain(PACKAGE);
+
   if([myapp initGULP:"gulp" :argc :argv] == nil) return 1;
   [myapp run];
   [myapp free];
