@@ -22,9 +22,12 @@
 #include <unistd.h>
 #include <time.h>
 #include <sys/stat.h>
+#include <config.h>
 #include "gtk/gtk.h"
 #include "logview.h"
+#if 0
 #include "close.xpm"
+#endif
 #include "gnome.h"
 
 #define INFO_WIDTH            350
@@ -62,7 +65,6 @@ LogInfo (GtkWidget * widget, gpointer user_data)
 {
    GtkWidget *frame;
    GtkWidget *vbox;
-   GtkWidget *icon;
    int h1, h2;
 
    if (curlog == NULL || loginfovisible)
@@ -75,7 +77,7 @@ LogInfo (GtkWidget * widget, gpointer user_data)
    gtk_signal_connect (GTK_OBJECT (InfoDialog), "delete_event",
 		       (GtkSignalFunc) CloseLogInfo,
 		       &InfoDialog);
-   gtk_window_set_title (GTK_WINDOW (InfoDialog), "Log stats");
+   gtk_window_set_title (GTK_WINDOW (InfoDialog), _("Log stats"));
    gtk_container_set_border_width (GTK_CONTAINER (InfoDialog), 0);
    gtk_widget_set_style (InfoDialog, cfg->main_style);
    gtk_widget_realize (InfoDialog);
@@ -135,7 +137,7 @@ RepaintLogInfo (GtkWidget * widget, GdkEventExpose * event)
    gdk_gc_set_foreground (gc, &cfg->blue);
    gdk_draw_rectangle (canvas, gc, TRUE, 3, 3, win_width - 6, h+6);
    gdk_gc_set_foreground (gc, &cfg->white);
-   gdk_draw_string (canvas, cfg->headingb, gc, x+3, y, "Log information");
+   gdk_draw_string (canvas, cfg->headingb, gc, x+3, y, _("Log information"));
    y += 9 + cfg->headingb->descent + cfg->fixedb->ascent;
 
 
@@ -152,17 +154,17 @@ RepaintLogInfo (GtkWidget * widget, GdkEventExpose * event)
 
    /* Draw Info */
    gdk_gc_set_foreground (gc, &cfg->black);
-   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, "Log:");
+   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, _("Log:"));
    y += h;
-   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, "Size:");
+   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, _("Size:"));
    y += h;
-   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, "Modified:");
+   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, _("Modified:"));
    y += h;
-   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, "Start date:");
+   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, _("Start date:"));
    y += h;
-   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, "Last date:");
+   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, _("Last date:"));
    y += h;
-   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, "Num. lines:");
+   gdk_draw_string (canvas, cfg->fixedb, gc, x, y, _("Num. lines:"));
 
    gdk_gc_set_font (gc, cfg->fixed);
 
@@ -178,7 +180,7 @@ RepaintLogInfo (GtkWidget * widget, GdkEventExpose * event)
    h = cfg->fixedb->descent + cfg->fixedb->ascent+2;
    gdk_draw_string (canvas, cfg->fixed, gc, x, y, buffer);
    y += h;
-   sprintf (buffer, "%ld bytes", (long) curlog->lstats.size);
+   sprintf (buffer, _("%ld bytes"), (long) curlog->lstats.size);
    gdk_draw_string (canvas, cfg->fixed, gc, x, y, buffer);
    y += h;
    sprintf (buffer, "%s ", ctime (&curlog->lstats.mtime));
