@@ -1,4 +1,6 @@
-
+#ifndef GNOMELOCALEDIR
+#define GNOMELOCALEDIR "/usr/share/locale"
+#endif
 /*  ----------------------------------------------------------------------
 
     Copyright (C) 1998  Cesar Miquel  (miquel@df.uba.ar)
@@ -26,7 +28,6 @@
 #include <sys/stat.h>
 #include "gtk/gtk.h"
 #include "logview.h"
-#include "close.xpm"
 #include "gnome.h"
 
 /*
@@ -78,66 +79,66 @@ GtkWidget *create_menu (char *item[], int n);
 
 
 GnomeUIInfo file_menu[] = {
-        {GNOME_APP_UI_ITEM, "Open log...            ", 
-	 "Open log", LoadLogMenu, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Open log...            "), 
+	 N_("Open log"), LoadLogMenu, NULL, NULL,
          GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, "Export log...          ", 
-	 "Export log", StubCall, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Export log...          "), 
+	 N_("Export log"), StubCall, NULL, NULL,
          GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, "Close log              ", 
-	 "Close log", CloseLogMenu, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Close log              "), 
+	 N_("Close log"), CloseLogMenu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, "Switch log             ", 
-	 "Switch log", change_log_menu, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Switch log             "), 
+	 N_("Switch log"), change_log_menu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, "Monitor..              ", 
-	 "Monitor log", MonitorMenu, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Monitor..              "), 
+	 N_("Monitor log"), MonitorMenu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, "Exit                   ", 
-	 "Exit program", ExitProg, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Exit                   "), 
+	 N_("Exit program"), ExitProg, NULL, NULL,
          GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'E', GDK_CONTROL_MASK, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
 GnomeUIInfo view_menu[] = {
-        {GNOME_APP_UI_ITEM, "Calendar                ", 
-	 "Show calendar log", CalendarMenu, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Calendar                "), 
+	 N_("Show calendar log"), CalendarMenu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 'C', GDK_CONTROL_MASK, NULL},
-        {GNOME_APP_UI_ITEM, "Log stats               ", 
-	 "Show log stats", LogInfo, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Log stats               "), 
+	 N_("Show log stats"), LogInfo, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 'I', GDK_CONTROL_MASK, NULL},
-        {GNOME_APP_UI_ITEM, "Zoom                    ", 
-	 "Show line info", create_zoom_view, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Zoom                    "), 
+	 N_("Show line info"), create_zoom_view, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 'Z', GDK_CONTROL_MASK, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
 GnomeUIInfo filter_menu[] = {
-        {GNOME_APP_UI_ITEM, "Select...               ", 
-	 "Select log events", StubCall, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Select...               "), 
+	 N_("Select log events"), StubCall, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_ITEM, "Filter..                ", 
-	 "Filter log events", StubCall, NULL, NULL,
+        {GNOME_APP_UI_ITEM, N_("Filter..                "), 
+	 N_("Filter log events"), StubCall, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
 GnomeUIInfo help_menu[] = {
-        {GNOME_APP_UI_ITEM, "About..                ", 
-	 "Info about logview", AboutShowWindow,
+        {GNOME_APP_UI_ITEM, N_("About..                "), 
+	 N_("Info about logview"), AboutShowWindow,
          NULL, NULL,
          GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
 GnomeUIInfo main_menu[] = {
-        {GNOME_APP_UI_SUBTREE, "File", NULL, file_menu, NULL, NULL,
+        {GNOME_APP_UI_SUBTREE, N_("File"), NULL, file_menu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_SUBTREE, "View", NULL, view_menu, NULL, NULL,
+        {GNOME_APP_UI_SUBTREE, N_("View"), NULL, view_menu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_SUBTREE, "Filter", NULL,  filter_menu, NULL, NULL,
+        {GNOME_APP_UI_SUBTREE, N_("Filter"), NULL,  filter_menu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
-        {GNOME_APP_UI_SUBTREE, "Help", NULL,  help_menu, NULL, NULL,
+        {GNOME_APP_UI_SUBTREE, N_("Help"), NULL,  help_menu, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
@@ -188,6 +189,9 @@ main (int argc, char *argv[])
 {
   /*  Initialize gnome & gtk */
   gnome_init ("logview", VERSION, argc, argv);
+
+  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+  textdomain (PACKAGE);
   
   /*  Load graphics config */
   cfg = CreateConfig();
@@ -222,7 +226,7 @@ InitApp ()
 
   /*  Read files and init data. */
   if (InitPages () < 0)
-    ShowErrMessage ("No log files to open");
+    ShowErrMessage (_("No log files to open"));
 
   /*  Remove about window */
   /* AboutHideWindow (); */
@@ -243,7 +247,6 @@ InitApp ()
 void
 CreateMainWin ()
 {
-   GtkWidget *window;
    GtkWidget *canvas;
    GtkWidget *box, *hbox, *hbox2;
    GtkWidget *frame, *padding;
@@ -252,7 +255,7 @@ CreateMainWin ()
 
    /* Create App */
 
-   app = gnome_app_new ("Logview", "System Log Viewer");
+   app = gnome_app_new ("Logview", _("System Log Viewer"));
 
    gtk_container_set_border_width ( GTK_CONTAINER (app), 3);
    gtk_signal_connect (GTK_OBJECT (app), "destroy",
@@ -332,7 +335,7 @@ CreateMainWin ()
    hbox2 = gtk_hbox_new (FALSE, 2);
    gtk_container_set_border_width ( GTK_CONTAINER (hbox2), 3);
 
-   label = (GtkLabel *)gtk_label_new ("Filename: ");
+   label = (GtkLabel *)gtk_label_new (_("Filename: "));
    gtk_label_set_justify (label, GTK_JUSTIFY_LEFT);
    gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (label), FALSE, FALSE, 0);
    gtk_widget_show (GTK_WIDGET (label));  
@@ -348,7 +351,7 @@ CreateMainWin ()
    gtk_widget_show (padding);
    gtk_box_pack_start (GTK_BOX (hbox2), padding, TRUE, TRUE, 0);
 
-   label = (GtkLabel *)gtk_label_new ("Date: ");
+   label = (GtkLabel *)gtk_label_new (_("Date: "));
    gtk_label_set_justify (label, GTK_JUSTIFY_RIGHT);
    gtk_widget_set_usize (GTK_WIDGET(label), 40, -1);
    gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (label), FALSE, FALSE, 0);
@@ -563,7 +566,7 @@ FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
    /* Check that we haven't opened all logfiles allowed    */
    if (numlogs >= MAX_NUM_LOGS)
      {
-       ShowErrMessage ("Too many open logs. Close one and try again");
+       ShowErrMessage (_("Too many open logs. Close one and try again"));
        return;
      }
 
@@ -618,7 +621,7 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
      return;
 
 
-   filesel = gtk_file_selection_new ("Open new logfile");
+   filesel = gtk_file_selection_new (_("Open new logfile"));
    gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), PATH_MESSAGES);
    gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
    gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
@@ -676,9 +679,8 @@ CloseApp ()
 void
 open_databases ()
 {
-  struct stat file_stat;
   char full_name[255];
-  int found, i;
+  int found;
 
   /* Find regexp DB -----------------------------------------------------  */
   found = FALSE;
